`xotl.tools.future.textwrap`:mod: - Text wrapping and filling
=============================================================

.. module:: xotl.tools.future.textwrap

This module complements the standard library's `textwrap`:mod:.

.. autofunction:: dedent
